You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@orc.apache.org by do...@apache.org on 2022/08/05 18:58:00 UTC

[orc] 02/02: ORC-1187: Use `main` instead of `master` in `merge_orc_pr.py`

This is an automated email from the ASF dual-hosted git repository.

dongjoon pushed a commit to branch branch-1.7
in repository https://gitbox.apache.org/repos/asf/orc.git

commit 584b359098bd06e5e7ca73689ba073b05e29d192
Author: Dongjoon Hyun <do...@apache.org>
AuthorDate: Tue May 24 09:27:16 2022 -0700

    ORC-1187: Use `main` instead of `master` in `merge_orc_pr.py`
    
    ### What changes were proposed in this pull request?
    
    This PR aims to revise `merge_orc_pr.py` to use `main` branch instead of `master`.
    
    ### Why are the changes needed?
    
    This is needed when the script update Apache ORC JIRA.
    
    ### How was this patch tested?
    
    Manual test.
    
    Closes #1139 from dongjoon-hyun/ORC-1187.
    
    Authored-by: Dongjoon Hyun <do...@apache.org>
    Signed-off-by: Dongjoon Hyun <do...@apache.org>
    (cherry picked from commit 8f038a068c61cdac72c4c58ad023ad3c4ab10e38)
    Signed-off-by: Dongjoon Hyun <do...@apache.org>
---
 dev/merge_orc_pr.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/dev/merge_orc_pr.py b/dev/merge_orc_pr.py
index 4917916d3..6aec3c3cd 100755
--- a/dev/merge_orc_pr.py
+++ b/dev/merge_orc_pr.py
@@ -237,7 +237,7 @@ def cherry_pick(pr_num, merge_hash, default_branch):
 
 def fix_version_from_branch(branch, versions):
     # Note: Assumes this is a sorted (newest->oldest) list of un-released versions
-    if branch == "master":
+    if branch == "main":
         return versions[0]
     else:
         branch_ver = branch.replace("branch-", "")
@@ -288,7 +288,7 @@ def resolve_jira_issue(merge_branches, comment, default_jira_id=""):
     )
     for v in default_fix_versions:
         # Handles the case where we have forked a release branch but not yet made the release.
         # In this case, if the PR is committed to the master branch and the release branch, we
         # only consider the release branch to be the fix version. E.g. it is not valid to have
         # both 1.1.0 and 1.0.0 as fix versions.
         (major, minor, patch) = v.split(".")
@@ -288,7 +288,7 @@ def resolve_jira_issue(merge_branches, comment, default_jira_id=""):
     for v in default_fix_versions:
         # Handles the case where we have forked a release branch but not yet made the release.
-        # In this case, if the PR is committed to the master branch and the release branch, we
+        # In this case, if the PR is committed to the main branch and the release branch, we
         # only consider the release branch to be the fix version. E.g. it is not valid to have
         # both 1.1.0 and 1.0.0 as fix versions.